@@ -4,7 +4,7 @@ use serde_json::Value;
 
 fn main() -> Result<(), Box<dyn Error>> {
     let mut client = FirebaseClient::new(std::env::var("FIREBASE_URL")?)?;
-    client.auth(std::env::var("FIREBASE_API_KEY")?);
+    client.auth(std::env::var("FIREBASE_ID_TOKEN")?);
 
     let reference = client.reference("/");
 
